Module unalloc

Module unalloc 

Structs

ColumnPattern
A learned column pattern from live records.
SignatureDb
Database of column patterns learned from live records.

Functions

carve_unallocated
Scan an unallocated region byte-by-byte looking for SQLite record patterns that match the learned signatures for table_hint.
learn_signatures
Analyse live records to learn the most common serial type per (table, col_index).
recover_layer6
Layer 6: carve records from all unallocated regions.